local show_players_in_sector = {}
show_players_in_sector.timer = Timer()
show_players_in_sector.last_player_list_string = ""
show_players_in_sector.sector_jump_detected = false
show_players_in_sector.sector_load_state = 0

function show_players_in_sector.is_pc_player(dest_player_name)
   if string.match(dest_player_name, "reading transponder") then
      return false
   end
   
   if string.match(dest_player_name, "^*") then
      return false
   end

   return true
end

function show_players_in_sector.populate_player(id, player)
   if not player then return end

   player.guild = GetGuildTag(id)
   player.name = GetPlayerName(id)
   player.faction = GetPlayerFaction(id)
end

function show_players_in_sector.add_player_to_player_list_str(player, player_list_str)
   if player == nil or player.name == nil then 
      return 
   end

   player_list_str = player_list_str .. " "
   if player.faction == nil or FactionColor_RGB[player.faction] == nil then
      player_list_str = player_list_str .. "\127ffffff"
   else
      player_list_str = player_list_str .. rgbtohex(FactionColor_RGB[player.faction])
   end
   if player.guild ~= nil and player.guild ~= "" then
      player_list_str = player_list_str .. "[" .. player.guild .. "] "   
   end
   player_list_str = player_list_str .. player.name
   return player_list_str
end

function show_players_in_sector.print_players()
   local player_list = {}
   ForEachPlayer(function (id)
		    if id ~= GetCharacterID() or id == 0 then
		       local dest_player_name = GetPlayerName(id)
      		       if dest_player_name and show_players_in_sector.is_pc_player(dest_player_name) then
			  local player = {}
			  show_players_in_sector.populate_player(id, player)
			  table.insert(player_list, player)
		       end
		    end
		 end)

   local player_list_str = ""
   for i,player in ipairs(player_list) do 
      player_list_str = show_players_in_sector.add_player_to_player_list_str(player, player_list_str) .. ", "
   end
   player_list_str = string.gsub(player_list_str, ", $", "")

   if player_list_str == "" then
      player_list_str = " <none>"
   end

   if show_players_in_sector.sector_jump_detected or show_players_in_sector.last_player_list_string ~= player_list_str then
      print("\127ff8000** \127ffffffPlayers in sector:"..player_list_str)
      show_players_in_sector.last_player_list_string  = player_list_str
      show_players_in_sector.sector_jump_detected = false
   end
end

function show_players_in_sector:OnEvent(event, data)
   if event == "PLAYER_ENTERED_SECTOR" or event == "PLAYER_LEFT_SECTOR" then
      if not data then return true end

      if show_players_in_sector.sector_load_state == 1 then
	 -- skip reporting, until 'me' new sector load is in progress
	 return true
      end

      local dest_player_name = GetPlayerName(data)
      if dest_player_name == nil then
	 return true
      end

      local its_me_jumping = (dest_player_name == GetPlayerName())
      if its_me_jumping and event == "PLAYER_LEFT_SECTOR" then
	 -- 'me' has jumped out of sector
	 show_players_in_sector.sector_load_state = 1
	 show_players_in_sector.timer:Kill()
	 return true
      end

      if not show_players_in_sector.is_pc_player(dest_player_name) then
	 return true
      end

      show_players_in_sector.timer:SetTimeout(200, function() show_players_in_sector.print_players() end)

   elseif event == "SECTOR_LOADED" then
      -- new sector loaded
      show_players_in_sector.sector_load_state = 2

   elseif event == "SHIP_SPAWN_CINEMATIC_FINISHED" then
      if show_players_in_sector.sector_load_state == 2 then
	 -- sector has been loaded and now 'me's ship has been spawned
	 show_players_in_sector.sector_jump_detected = true
	 show_players_in_sector.sector_load_state = 0
      end
   end
end

RegisterEvent(show_players_in_sector, "SECTOR_LOADED")
RegisterEvent(show_players_in_sector, "SHIP_SPAWN_CINEMATIC_FINISHED")
RegisterEvent(show_players_in_sector, "PLAYER_ENTERED_SECTOR")
RegisterEvent(show_players_in_sector, "PLAYER_LEFT_SECTOR")
